@@ -1,15 +1,25 @@
 import sys
+import inspect
 
 argv = sys.argv
 argument_dict = {}
 
-def set(argument, argument_type=str, default=None, help_message=None):
+
+def set(argument, argument_type=str, default=None, help_message=None,
+        mandatory=False):
+
     argument_dict[argument] = {
         'default': default,
         'type': argument_type,
         'help': help_message
     }
 
+    if mandatory and not check(argument):
+        exit(documentation())
+
+    return get(argument)
+
+
 def get(argument):
     if argument in argv and argv.index(argument) < len(argv):
         value_index = argv.index(argument) + 1
@@ -26,9 +36,22 @@ def get(argument):
 
     return argument_value
 
+
 def check(argument):
     return argument in argv
 
+
+def function(target):
+    argument_value = {}
+    function_arguments = str(inspect.signature(target))[1:-1].split(', ')
+
+    for argument in function_arguments:
+        argument = argument.split('=')
+        argument_value[argument[0]] = get(argument[0])
+
+    target(**argument_value)
+
+
 def documentation():
     documentation_message = f'{argv[0]} usage:\n\n'
     documentation_message += 'Parameters:\n'
@@ -39,6 +62,6 @@ def documentation():
         argument_help = argument_dict[argument]['help']
 
         documentation_message += f'\t{argument}: {argument_help} ' \
-            f'(Type: {argument_type}, Default: {argument_default})'
+            f'(Type: {argument_type}, Default: {argument_default})\n'
 
-    return documentation_message
\ No newline at end of file
+    return documentation_message
